@@ -1,11 +1,16 @@
 from .gitignoreList import gitignore
 
+licenses = [
+    "None",
+    "MIT",
+    "Gnu gpl v3",
+    "Apache license 2.0",
+    "Gnu AGPL v3",
+    "Mozilla public license 2.0",
+]
+
 questions = [
-    {
-        "type": "input",
-        "name": "repo_name",
-        "message": "Enter the name of your repo : ",
-    },
+    {"type": "input", "name": "repo_name", "message": "Enter the name of your repo : "},
     {
         "type": "input",
         "name": "description",
@@ -21,7 +26,13 @@ questions = [
         "type": "list",
         "name": "gitginore_template",
         "message": "Select gitginore template for your repo",
-        "choices": gitignore,
+        "choices": [g.split(".")[0] for g in gitignore],
+    },
+    {
+        "type": "list",
+        "name": "license_name",
+        "message": "choose a license",
+        "choices": licenses,
     },
     {
         "type": "confirm",
@@ -32,5 +43,5 @@ questions = [
         "type": "input",
         "name": "remote_name",
         "message": "input your remote name name(default:origin)",
-    }
+    },
 ]
